@@ -28,6 +28,8 @@ import pytest
 from airflow.models import Connection
 from airflow.providers.oracle.hooks.oracle import OracleHook
 
+from unit.oracle.test_utils import mock_oracle_lob
+
 
 class TestOracleHookConn:
     def setup_method(self):
@@ -266,7 +268,7 @@ class TestOracleHookConn:
             self.db_hook.get_conn()
 
     @pytest.mark.parametrize(
-        "connection_params, expected_uri",
+        ("connection_params", "expected_uri"),
         [
             pytest.param(
                 {"extra": '{"service_name": "service"}', "schema": None, "port": 1521},
@@ -309,6 +311,27 @@ class TestOracleHookConn:
         uri = self.db_hook.get_uri()
         assert uri == expected_uri
 
+    @mock.patch("airflow.providers.oracle.hooks.oracle.oracledb.connect")
+    def test_get_conn_with_various_params(self, mock_connect):
+        """Verify wallet/SSL, connection class, and pool parameters
+        are passed to oracledb.connect."""
+        params = {
+            "wallet_location": "/tmp/wallet",
+            "wallet_password": "secret",
+            "ssl_server_cert_dn": "CN=dbserver,OU=DB,O=Oracle,L=BLR,C=IN",
+            "ssl_server_dn_match": True,
+            "cclass": "MY_APP_CLASS",
+            "pool_name": "POOL_1",
+        }
+        self.connection.extra = json.dumps(params)
+        self.db_hook.get_conn()
+
+        assert mock_connect.call_count == 1
+        _, kwargs = mock_connect.call_args
+
+        for key, value in params.items():
+            assert kwargs[key] == value
+
 
 class TestOracleHook:
     def setup_method(self):
@@ -419,7 +442,7 @@ class TestOracleHook:
 
     def test_bulk_insert_rows_no_rows(self):
         rows = []
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match="parameter rows could not be None or empty iterable"):
             self.db_hook.bulk_insert_rows("table", rows)
 
     def test_bulk_insert_sequence_field(self):
@@ -436,18 +459,21 @@ class TestOracleHook:
         self.cur.executemany.assert_called_once_with(None, rows)
 
     def test_bulk_insert_sequence_without_parameter(self):
+        SEQUENCE_COLUMN_OR_NAME_PROVIDED = (
+            "Parameters 'sequence_column' and 'sequence_name' must be provided together or not at all."
+        )
         rows = [(1, 2, 3), (4, 5, 6), (7, 8, 9)]
         target_fields = ["col1", "col2", "col3"]
         sequence_column = "id"
         sequence_name = None
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match=SEQUENCE_COLUMN_OR_NAME_PROVIDED):
             self.db_hook.bulk_insert_rows(
                 "table", rows, target_fields, sequence_column=sequence_column, sequence_name=sequence_name
             )
 
         sequence_column = None
         sequence_name = "my_sequence"
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match=SEQUENCE_COLUMN_OR_NAME_PROVIDED):
             self.db_hook.bulk_insert_rows(
                 "table", rows, target_fields, sequence_column=sequence_column, sequence_name=sequence_name
             )
@@ -521,7 +547,70 @@ class TestOracleHook:
         assert result == expected
 
     def test_test_connection_use_dual_table(self):
+        self.cur.fetchone.return_value = (1,)
         status, message = self.db_hook.test_connection()
         self.cur.execute.assert_called_once_with("select 1 from dual")
         assert status is True
         assert message == "Connection successfully tested"
+
+    def test_get_openlineage_database_info_with_service_name(self):
+        conn = Connection(
+            conn_id="oracle_default",
+            conn_type="oracle",
+            host="localhost",
+            port=1521,
+            extra='{"service_name": "ORCLPDB1"}',
+        )
+        hook = OracleHook(oracle_conn_id="oracle_default")
+        hook.get_connection = lambda _: conn
+
+        assert hook.service_name == "ORCLPDB1"
+        db_info = hook.get_openlineage_database_info(conn)
+        assert db_info.scheme == "oracle"
+        assert db_info.authority == "localhost:1521"
+        assert db_info.database == "ORCLPDB1"
+        assert db_info.normalize_name_method("employees") == "EMPLOYEES"
+        assert db_info.information_schema_table_name == "ALL_TAB_COLUMNS"
+        assert "owner" in db_info.information_schema_columns
+
+    def test_get_openlineage_database_info_with_sid(self):
+        conn = Connection(
+            conn_id="oracle_default",
+            conn_type="oracle",
+            host="dbhost",
+            port=1521,
+            extra='{"sid": "XE"}',
+        )
+        hook = OracleHook(oracle_conn_id="oracle_default")
+        hook.get_connection = lambda _: conn
+
+        assert hook.sid == "XE"
+        db_info = hook.get_openlineage_database_info(conn)
+        assert db_info.scheme == "oracle"
+        assert db_info.authority == "dbhost:1521"
+        assert db_info.database == "XE"
+        assert db_info.normalize_name_method("employees") == "EMPLOYEES"
+        assert db_info.information_schema_table_name == "ALL_TAB_COLUMNS"
+        assert "owner" in db_info.information_schema_columns
+
+    def test_get_first(self):
+        statement = "SQL"
+
+        self.cur.fetchone.return_value = (mock_oracle_lob("hello"),)
+
+        assert self.db_hook.get_first(statement) == ("hello",)
+
+        assert self.conn.close.call_count == 1
+        assert self.cur.close.call_count == 1
+        self.cur.execute.assert_called_once_with(statement)
+
+    def test_get_records(self):
+        statement = "SQL"
+
+        self.cur.fetchall.return_value = (mock_oracle_lob("hello"),), (mock_oracle_lob("world"),)
+
+        assert self.db_hook.get_records(statement) == [("hello",), ("world",)]
+
+        assert self.conn.close.call_count == 1
+        assert self.cur.close.call_count == 1
+        self.cur.execute.assert_called_once_with(statement)
